@@ -19,9 +19,9 @@
 #include <string.h>
 #include <syslog.h>
 
-#include <loc/libloc.h>
-#include <loc/database.h>
-#include <loc/writer.h>
+#include <libloc/libloc.h>
+#include <libloc/database.h>
+#include <libloc/writer.h>
 
 #define TEST_AS_COUNT 5000
 
